<?php
/*
Plugin Name: WP Pro Ad System
Plugin URI: http://www.wpplugins.be/wp-pro-advertising-system/
Description: Plugin to manage advertisements on your website.
Author: Niels M.
Version: 2.1
Author URI: http://www.nielsmusschoot.com
*/


require_once('functions.php');
require_once('includes/display_ads.php');


//Plugin Path
$wp_ads_path = WP_PLUGIN_URL.'/'.str_replace(basename( __FILE__),"",plugin_basename(__FILE__));
$wp_ads_abs_path = ABSPATH. 'wp-content/plugins/' .str_replace(basename( __FILE__),"",plugin_basename(__FILE__));
$wp_ads_role_admin = 'add_users';

// Option Variables
if( function_exists( 'pro_ads_load_options' )){ $set = pro_ads_load_options(); } 
define('SHOW_EMPTY_ADZONES', $set[0]->show_empty_adzones);
//define('SHOW_EMPTY_ADZONES', 1);


// Load jQuery into the theme
function wp_pro_ad_init_method() {
    global $wp_ads_path;
	wp_enqueue_script('jquery');
	wp_enqueue_script('pro_ads_load_ads', $wp_ads_path.'templates/js/load_ads.js');
	
	load_plugin_textdomain('wpproads', false, basename( dirname( __FILE__ ) ) . '/localization' );
	
	if(!is_admin())
	{
		if( function_exists( 'pro_ad_finish_campaigns' )){ pro_ad_finish_campaigns(); }
		if( function_exists( 'pro_ad_finish_banners' ) ){ pro_ad_finish_banners(); }
	}
}    
add_action('init', 'wp_pro_ad_init_method');



// Button to admin page
function wp_pro_ad_admin_actions() 
{
	global $wp_ads_role_admin, $wp_ads_path;
	
	
	if(is_admin() && isset($_GET['page']))
	{
		if( 
			$_GET['page'] == 'wp-pro-advertising' || 
			$_GET['page']=='wp-pro-ads-stats' || 
			$_GET['page']=='wp-pro-ads-add-ons' || 
			$_GET['page']=='wp-pro-ads-options' || 
			$_GET['page']=='wp-pro-advertising-buy-sell' ||
			$_GET['page']=='wp-pro-ads-stats-buy-sell'
		 ){
			// Load stylesheets
			wp_enqueue_style("wp_pro_ads_style", $wp_ads_path."templates/css/style.css", false, "2.0", "all");
			
			// Load jQuery
			wp_enqueue_script('jquery');
			wp_enqueue_script('jquery-ui-core');
			wp_enqueue_script('jquery-ui-dialog');
			wp_enqueue_script('jquery-ui-datepicker', $wp_ads_path.'templates/js/jquery-ui-1.8.16.datepicker.js', array('jquery','jquery-ui-core') );
			
			wp_enqueue_style( 'jquery_ui_style', $wp_ads_path.'templates/css/jquery-ui-1.8.13.custom.css');
			
			// Load tooltips
			wp_enqueue_script( 'pro_ad_tooltip_', $wp_ads_path.'templates/js/jquery.tipTip.minified.js');
			wp_enqueue_style( 'pro_ad_tooltip_style', $wp_ads_path.'templates/css/tooltips.css');
		}
	}
	
	// Create menu
	if (function_exists('add_object_page')) 
	{
		add_object_page(__('Advertising','wpproads'), __('Advertising','wpproads'), $wp_ads_role_admin, "wp-pro-advertising" , "wp_pro_ad_settings", $wp_ads_path."images/banner_icon.png");
	}
	else
	{
		add_menu_page(__('Advertising','wpproads'), __('Advertising','wpproads'), $wp_ads_role_admin,  "wp-pro-advertising" , "wp_pro_ad_settings");
	}
	
	add_submenu_page("wp-pro-advertising", __('Main Settings','wpproads'), __('Main Settings','wpproads'), $wp_ads_role_admin, "wp-pro-advertising", "wp_pro_ad_settings");
	add_submenu_page("wp-pro-advertising", __('Statistics','wpproads'), __('Statistics','wpproads'), $wp_ads_role_admin, "wp-pro-ads-stats", "wp_pro_ad_stats");
	add_submenu_page("wp-pro-advertising", __('Add-Ons','wpproads'), __('Add-Ons','wpproads'), $wp_ads_role_admin, "wp-pro-ads-add-ons", "wp_pro_ad_addons");
	add_submenu_page("wp-pro-advertising", __('Options','wpproads'), __('Options','wpproads'), $wp_ads_role_admin, "wp-pro-ads-options", "wp_pro_ad_options");
}
add_action('admin_menu', 'wp_pro_ad_admin_actions');



// MENU FUNCTIONS
function wp_pro_ad_settings()
{
	include('templates/pro_ad_settings.php');
}
function wp_pro_ad_stats()
{
	include('templates/pro_ad_stats.php');
}
function wp_pro_ad_addons()
{
	include('templates/pro_ad_addons.php');
}
function wp_pro_ad_options()
{
	include('templates/pro_ad_options.php');
}




// Create Database
function create_pro_ad_db_tables()
{
	global $wpdb, $wp_ads_abs_path;
	require_once(ABSPATH . 'wp-admin/upgrade-functions.php');
	
	$table_advertisers = $wpdb->prefix . "ad_pro_system_advertisers";
	$table_campaigns   = $wpdb->prefix . "ad_pro_system_campaigns";
	$table_banners     = $wpdb->prefix . "ad_pro_system_banners";
	$table_adzones     = $wpdb->prefix . "ad_pro_system_adzones";
	$table_stats       = $wpdb->prefix . "ad_pro_system_stats";
	$table_linked      = $wpdb->prefix . "ad_pro_system_linked";
	$table_list_addons = $wpdb->prefix . "ad_pro_system_list_addons";
	$table_options     = $wpdb->prefix . "ad_pro_system_options";
   
    $sql_advertisers = "CREATE TABLE " . $table_advertisers . " (
		id mediumint(9) NOT NULL AUTO_INCREMENT,
	    name varchar(200) NOT NULL,
	    email varchar(200) NOT NULL,
		wp_user_id mediumint(9) NOT NULL,
	    UNIQUE KEY id (id)
	);";
	
	$sql_campaigns = "CREATE TABLE " . $table_campaigns . " (
		id mediumint(9) NOT NULL AUTO_INCREMENT,
	    advertiser_id mediumint(9) NOT NULL,
	    name varchar(200) NOT NULL,
		start_date varchar(50) NOT NULL,
	    end_date varchar(50) NOT NULL,
		status varchar(50) NOT NULL,
	    UNIQUE KEY id (id)
	);";
	
	$sql_banners = "CREATE TABLE " . $table_banners . " (
		id mediumint(9) NOT NULL AUTO_INCREMENT,
	    advertiser_id mediumint(9) NOT NULL,
	    campaign_id mediumint(9) NOT NULL,
		name varchar(200) NOT NULL,
		file varchar(300) NOT NULL,
		ext_file varchar(300) NOT NULL,
		size varchar(100) NOT NULL,
		custom_size varchar(100) NOT NULL,
		html text NOT NULL,
		add_timestamp varchar(10) NOT NULL,
		url text NOT NULL,
		target varchar(50) NOT NULL,
		adzone varchar(200) NOT NULL,
		country varchar(50) NOT NULL,
		status varchar(50) NOT NULL,
		plan varchar(10) NOT NULL,
		start_date datetime,
		end_date datetime,
	    UNIQUE KEY id (id)
	);";
	
	$sql_adzones = "CREATE TABLE " . $table_adzones . " (
		id mediumint(9) NOT NULL AUTO_INCREMENT,
	    name varchar(200) NOT NULL,
		description text NOT NULL,
		size varchar(100) NOT NULL,
		atonce varchar(50) NOT NULL,
		custom int(2) NOT NULL,
		rotation int(5) NOT NULL,
		rotation_time int(10) NOT NULL,
		banner_price decimal(20,2) NOT NULL,
	    UNIQUE KEY id (id)
	);";
	
	$sql_stats = "CREATE TABLE " . $table_stats . " (
		id mediumint(9) NOT NULL AUTO_INCREMENT,
	    advertiser_id mediumint(9) NOT NULL,
		campaign_id mediumint(9) NOT NULL,
		banner_id mediumint(9) NOT NULL,
		adzone_id mediumint(9) NOT NULL,
		date varchar(200) NOT NULL,
		ip_address varchar(50) NOT NULL,
		clicks text NOT NULL,
		impressions text NOT NULL,
	    UNIQUE KEY id (id)
	);";
	
	$sql_linked = "CREATE TABLE " . $table_linked . " (
		id mediumint(9) NOT NULL AUTO_INCREMENT,
	    advertiser_id mediumint(9) NOT NULL,
		campaign_id mediumint(9) NOT NULL,
		banner_id mediumint(9) NOT NULL,
		adzone_id mediumint(9) NOT NULL,
	    UNIQUE KEY id (id)
	);";
	
	$sql_list_addons = "CREATE TABLE " . $table_list_addons . " (
		id mediumint(9) NOT NULL AUTO_INCREMENT,
		addon_id int(10) NOT NULL,
	    name varchar(200) NOT NULL,
		version varchar(50) NOT NULL,
		description text NOT NULL,
		installed int(5) NOT NULL,
		link varchar(300) NOT NULL,
		path text NOT NULL,
	    UNIQUE KEY id (id)
	);";
	
	$sql_options = "CREATE TABLE " . $table_options . " (
		id mediumint(9) NOT NULL AUTO_INCREMENT,
	    show_empty_adzones mediumint(5) NOT NULL,
	    UNIQUE KEY id (id)
	);";
	
	if($wpdb->get_var("show tables like '".$table_options."'") != $table_options)
	{
		dbDelta($sql_advertisers);
		dbDelta($sql_campaigns);
		dbDelta($sql_banners);
		dbDelta($sql_adzones);
		dbDelta($sql_stats);
		dbDelta($sql_linked);
		dbDelta($sql_list_addons);
		dbDelta($sql_options);
		
		if($wpdb->get_var("show tables like '".$table_adzones."'") != $table_adzones)
		{
			$results = $wpdb->query( "INSERT INTO ".$table_adzones." SET name = 'Default adzone', 
																     description = 'This is a default adzone. You can edit or delete this if you like.',
																	 size = '728x90' ");
		}
		
		// Preset options database
		$results = $wpdb->query( "INSERT INTO ".$table_options." SET show_empty_adzones = '1' ");
		
		
	}
	else
	{
		dbDelta($sql_advertisers);
		dbDelta($sql_campaigns);
		dbDelta($sql_banners);
		dbDelta($sql_adzones);
		dbDelta($sql_stats);
		dbDelta($sql_list_addons);
		dbDelta($sql_options);
	}
}
add_action('admin_head', 'create_pro_ad_db_tables');








/*
 * DISPLAY AD ZONE
*/
function pro_ad_display_adzone( $id )
{
	global $wpdb, $current_user;
	
	$res = pro_ad_load_adzones( "WHERE id = '".$id."' LIMIT 1" );
	 
	$ads = $wpdb->get_results("SELECT b.*, l.adzone_id, c.status
								FROM 
								 
							   " . $wpdb->prefix . "ad_pro_system_banners b, 
							   " . $wpdb->prefix . "ad_pro_system_linked l,
							   " . $wpdb->prefix . "ad_pro_system_campaigns c  
							   
							   
							   WHERE 
							   b.status = 1 AND 
							   l.banner_id = b.id AND 
							   l.adzone_id = '".$id."' AND 
							   c.advertiser_id = b.advertiser_id AND 
							   c.id = l.campaign_id AND 
							   c.status = 1 
							   
							   ORDER BY RAND()");
	
	
	$size = explode( 'x', $res[0]->size );
	
	if( !$res[0]->atonce )
	{
		$string = pro_ad_display_single( $id, $res, $ads, $size );
	}
	else
	{
		$string = pro_ad_display_multiple( $id, $res, $ads, $size );
	}
	
	if( !SHOW_EMPTY_ADZONES && !count( $ads ) ): 
		// Empty adzones are not showing
	else:
		return $string;
	endif;
}



//Shortcode function
//[pro_ad_display_adzone id="1"]
function sc_pro_ad_display_adzone( $atts, $content = null ) 
{
   	extract( shortcode_atts( array(
   		'id' => 1
    ), $atts ) );
	
	return pro_ad_display_adzone( esc_attr($id) );
}
add_shortcode('pro_ad_display_adzone', 'sc_pro_ad_display_adzone');



/*
 * Banner click
*/
function pro_ad_click_action()
{
	if ( isset($_GET['ad_click']) )
	{
		require_once('includes/redirect.php');
	}
}
add_action('wp_loaded','pro_ad_click_action');



/*
 * Create adzone widgets
*/
class pro_ad_adzone_widgets extends WP_Widget {

	function pro_ad_adzone_widgets() {
		$widget_ops = array('classname' => 'pro_ad_adzone', 'description' => __( 'Display your ads.') );
		$this->WP_Widget('pro_ad_adzone_widgets', __('Display your ads.'), $widget_ops);
	}
	
	function widget($args,$instance) {
	
		extract($args);
		
		if( !empty( $instance['adzone_id'] ))
		{
			echo pro_ad_display_adzone( $instance['adzone_id'] );
		}
	}
	
	
	function update($new_instance,$old_instance) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['adzone_id'] = $new_instance['adzone_id'];

		return $instance;
	}

	function form($instance) {
		
		//Defaults
		$instance = wp_parse_args( (array) $instance, array( 'adzone_id' => ''));
		?>
        <p>
        	<label for="<?php echo $this->get_field_id('adzone_id'); ?>"><?php _e('Select your adzone:'); ?></label> 
			<select id="<?php echo $this->get_field_id( 'adzone_id' ); ?>" name="<?php echo $this->get_field_name( 'adzone_id' ); ?>" width="20%">
            
            	<?php
				$adzones = pro_ad_load_adzones();
				foreach( $adzones as $i => $adzone )
				{
					?>
					<option value="<?php echo $adzone->id; ?>" <?php if ( $adzone->id == $instance['adzone_id'] ) echo 'selected="selected"'; ?>>
						<?php echo $adzone->name; ?>
                    </option>
                    <?php
				}
				?>
				
			</select>
		</p><?php
	}
}

function pro_ad_adzone_widgets_init() {
	register_widget('pro_ad_adzone_widgets');
}

add_action('widgets_init', 'pro_ad_adzone_widgets_init');



/*
 * Custom Plugin Updater
*/
include_once( 'class-pro-ad-system-updater.php' );
$pro_ads_updater = new Pro_Ad_System_Updater( 'http://www.wpplugins.be/updates/api/', __FILE__, array( 'licence_key' => get_option( 'mdp_update_access_key' ) ) );
?>